.. include:: ../README.rst

----

.. toctree::
   :maxdepth: 2

   usage
   api
   contributing
   changelog


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
